@@ -74,7 +74,10 @@ BarcodeDetector::~BarcodeDetector() {
 }
 
 int BarcodeDetector::analyseImage(char *buffer, char *fourcc, int bpp) {
-    // stop this code running as it's segfaulting atm
+
+    if(scanning_status==false)
+        return 0;
+
     if (!this->dmtx_thread.isRunning())
         dmtx_thread.start();
     else if(!this->dmtx_thread.isDecoding) {
@@ -240,43 +243,3 @@ QImage *BarcodeDetector::getLastImage() {
     return qi;
 }
 
-void BarcodeDetector::start() {
-    // start the pipeline and decoding
-    //this->scanning_status = true;
-    //this->pipeline;
-
-}
-
-void BarcodeDetector::stop()
-{
-    // stop the pipeline and decoding
-//    self->scanning_status = false;
-}
-
-void BarcodeDetector::doFocus()
-{
-    // Autofocus
-//    if (self->scanning_status){
-//        gst_element_set_state (pipeline, GST_STATE_PAUSED);
-//        gst_photography_set_scene_mode (GST_PHOTOGRAPHY (camera_src), GST_PHOTOGRAPHY_SCENE_MODE_CLOSEUP);
-//        gst_photography_set_autofocus(GST_PHOTOGRAPHY(camera_src), TRUE);
-//        gst_element_set_state (pipeline, GST_STATE_READY);
-//       gst_element_set_state (pipeline, GST_STATE_PLAYING);
-//    }
-}
-
-void BarcodeDetector::loadFromFile()
-{
-    // load an image from file and feed it to the decoders
-}
-
-
-void BarcodeDetector::dmtxCallback()
-{
-    // callback for dmtx GStreamer element
-}
-
-void BarcodeDetector::zbarCallback()
-{
-    // callback for ZBar GStreamer element
-}
