@@ -70,4 +70,8 @@
 #define DBUS_FOCUS_BUTTON "/org/freedesktop/Hal/devices/platform_cam_focus"
 #define DBUS_RELEASE_BUTTON "/org/freedesktop/Hal/devices/platform_cam_launch"
 
+// Default settings
+
+#define CONTINUOUS_SCANNING_DEFAULT true
+
 #endif // COMMON_H
