@@ -147,15 +147,6 @@ MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
 
     ////videoWidget->setMinimumSize(640,400);
 
-
-    if(settings->value("continous_scanning").toBool()){
-        videoWidget->setContinuousScanning(true);
-        this->continuousScanningMode = true;
-    }else{
-        videoWidget->setContinuousScanning(false);
-        this->continuousScanningMode = false;
-    }
-
     // connect the signal from the barcode decoder
     qDebug() << "MainWindow::MainWindow(): Connecting signals";
     connect(decoder, SIGNAL(imageAnalysed(QString, QString, QImage*)),
