@@ -31,13 +31,23 @@
 //along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QtGui/QApplication>
-#include "maemobarcodewindow.h"
 #include <QtDBus>
+#include <QSplashScreen>
+#include <QPixmap>
+#include "maemobarcodewindow.h"
 
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
+    qDebug() << "main(): Started mbarcode";
 
+    qDebug() << "main(): Showing splash";
+    QPixmap pixmap(":/images/splash.png");
+    QSplashScreen splash(pixmap);
+    splash.show();
+    a.processEvents();
+
+    qDebug() << "main(): Showing window";
     MaemoBarcodeWindow w;
 
     if (!QDBusConnection::sessionBus().isConnected()) {
@@ -58,7 +68,7 @@ int main(int argc, char *argv[])
         exit(3);
     }
 
-    if(w.settings->value("showFullScreen", true).toBool()) {
+    if(w.settings->value("use_full_screen", true).toBool()) {
         w.showFullScreen(); // showFullScreen increases performance drastically using openGL - loses menus though...
     } else {
         w.show();
