@@ -11,7 +11,7 @@ class PluginInterface;
 class PluginSettings : public QMainWindow {
     Q_OBJECT
 public:
-    PluginSettings(QSet<PluginInterface*> pluginInterfaces, QWidget *parent = 0);
+    PluginSettings(QList<PluginInterface*> pluginInterfaces, QWidget *parent = 0);
     ~PluginSettings();
 
     QStandardItemModel *model;
