@@ -38,6 +38,8 @@
 #include "pluginaction.h"
 #include "plugininterfaces.h"
 #include "pluginintermediate.h"
+#include <QTimer>
+#include <QItemSelectionModel>
 
 ResultsWindow::ResultsWindow(QWidget *parent) :
         QMainWindow(parent),
@@ -49,6 +51,9 @@ ResultsWindow::ResultsWindow(QWidget *parent) :
     setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->tblResults->setItemDelegate(new PluginActionListDelegate(this));
     ui->tblResults->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+
+    selectionTimer = new QTimer(this);
+    connect(selectionTimer, SIGNAL(timeout()), this, SLOT(selectionTimerExpiry()));
 }
 
 ResultsWindow::~ResultsWindow()
@@ -174,7 +179,20 @@ QVariant PluginActionListModel::data(const QModelIndex &index, int role) const {
 void ResultsWindow::on_tblResults_clicked(QModelIndex index)
 {
     PluginAction *plugin = qVariantValue<PluginAction*>(index.data());
-    // really need to show the use some visual indication here that they have pressed a "button"
-    // I've no clue how to do this yet though....
+
+    // start a timer whose callback will remove the selection that has just happened in the QTableView
+    selectionTimer->stop();
+
+    selectionTimer->start(1000);
+
+
     plugin->clickAction(this);
 }
+
+void ResultsWindow::selectionTimerExpiry()
+{
+    qDebug() << "Selection timer expiry";
+    selectionTimer->stop(); // we don't want to be called again
+    QItemSelectionModel *selection = ui->tblResults->selectionModel();
+    selection->clear();
+}
