@@ -54,8 +54,8 @@ void SettingsWindow::showEvent(QShowEvent *) {
     ui->chkAutofocus->setChecked(settings->value("use_autofocus", true).toBool());
     ui->chkFullScreen->setChecked(settings->value("use_full_screen", true).toBool());
     ui->spnAutoFocusDelay->setValue(settings->value("autofocus_delay", 2.0).toDouble());
-    ui->radioButtonContinuousScanning->setChecked(settings->value("continous_scanning").toBool());
-    ui->radioButtonPressToScan->setChecked(!settings->value("continous_scanning").toBool());
+    ui->radioButtonContinuousScanning->setChecked(settings->value("continous_scanning", CONTINUOUS_SCANNING_DEFAULT).toBool());
+    ui->radioButtonPressToScan->setChecked(!settings->value("continous_scanning", CONTINUOUS_SCANNING_DEFAULT).toBool());
 }
 
 void SettingsWindow::changeEvent(QEvent *e)
