@@ -87,7 +87,6 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     qDebug() << "VideoWidget::VideoWidget(): Pipeline initialized";
     this->decoder = decoder; // create a new decoder object
 
-
     continuousFocusInterval = 3000;
     refocusTimer = new QTimer(this);
     connect(refocusTimer, SIGNAL(timeout()), this, SLOT(refocus()));
@@ -351,10 +350,17 @@ void VideoWidget::paintGL() {
         painter.drawRect(width() / 8,0, width() / 8 * 6, height() / 8);
         painter.drawRect(width() / 8,height() / 8 * 7, width() / 8 * 6, height() / 8);
 
-        // Give the user some info about what's going on, and place it in the top 8th part
+        // Give the user some info about what's going on, and place it in the top xth part
         painter.setPen(Qt::white);
-        painter.drawText(QRect(0,0,width(),height() / 8), Qt::AlignCenter, tr("Place a barcode in the square below to scan"));
+        painter.drawText(QRect(0,0,width(),height() / 16), Qt::AlignCenter, tr("Place a barcode in the square below"));
+        QString continuousText;
+        if(!parent->continuousScanningMode) {
+            continuousText = tr("and press camera button to start scanning.");
+        } else {
+            continuousText = tr("to let the automatic scanner detect it.");
 
+        }
+        painter.drawText(QRect(0,height()/16,width(),height() / 16), Qt::AlignCenter, continuousText);
 
     } else { // if the pipeline is not ready, let us write a message to our user
 
@@ -427,6 +433,14 @@ void VideoWidget::start(bool evenIfNotYetStarted) {
         keepRunning = true;
         timerOpenGL->setInterval(PAINTGL_INTERVAL_HIGH);
     }
+    // see if the settings wants us to have continuous scanning enabled
+    if(parent->settings->value("continous_scanning",CONTINUOUS_SCANNING_DEFAULT).toBool()){
+        setContinuousScanning(true);
+        parent->continuousScanningMode = true;
+    }else{
+        setContinuousScanning(false);
+        parent->continuousScanningMode = false;
+    }
 }
 void VideoWidget::stop(bool stopCompletely) {
     qDebug() << "VideoWidget::stop(): Called with stopCompletely = " << stopCompletely;
@@ -882,7 +896,7 @@ void VideoWidget::mousePressEvent(QMouseEvent *event){
 void VideoWidget::startTimedScan(int time)
 {
     // enable scanning in the decoder class
-    setContinuousScanning(true);
+    decoder->scanning_status=true;
 
     // add some sort of graphical notification so people know we're scanning
 
@@ -900,15 +914,12 @@ void VideoWidget::stopTimedScan()
     // disable the timer (does this automatically occur anyway?)
     timedScanTimer->stop();
     // disable scanning in the decoder thread
-    setContinuousScanning(false);
+    decoder->scanning_status=false;
 
     // remove graphical notification that we're scanning
 }
 
 void VideoWidget::setContinuousScanning(bool on)
 {
-    if (on==true)
-        decoder->scanning_status=true;
-    else
-        decoder->scanning_status=false;
+    decoder->scanning_status=on;
 }
